@@ -1,12 +1,21 @@
 # Copyright 2022, Red Hat, Inc.
 # SPDX-License-Identifier: LGPL-2.1-or-later
 
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
+
+REMEDIATION_JSON_KEYS = [
+    "remediation_id",
+    "system",
+    "complexity",
+    "disruption",
+    "strategy",
+    "fix",
+]
 
 
 @dataclass
 class Remediation:
-    remediation_id: str = ""
+    remediation_id: str
     system: str = ""
     complexity: str = ""
     disruption: str = ""
@@ -14,14 +23,7 @@ class Remediation:
     fix: str = ""
 
     def as_dict(self):
-        return {
-            "remediation_id": self.remediation_id,
-            "system": self.system,
-            "complexity": self.complexity,
-            "disruption": self.disruption,
-            "strategy": self.strategy,
-            "fix": self.fix,
-        }
+        return asdict(self)
 
     def get_type(self):
         script_types = {
