@@ -11,7 +11,8 @@ from unittest import mock
 import pytest
 
 from openscap_report.cli import CommandLineAPI
-from openscap_report.scap_results_parser import SCAPResultsParser
+from openscap_report.scap_results_parser import (ARF_SCHEMAS_PATH,
+                                                 SCAPResultsParser)
 
 from ..constants import PATH_TO_ARF, PATH_TO_EMPTY_FILE
 
@@ -38,7 +39,7 @@ def test_load_file(mock_args):  # pylint: disable=W0613
     api = CommandLineAPI()
     xml_report = api.load_file()
     parser = SCAPResultsParser(xml_report)
-    assert parser.validate(parser.arf_schemas_path)
+    assert parser.validate(ARF_SCHEMAS_PATH)
     api.close_files()
 
 
@@ -76,6 +77,34 @@ def test_command_with_input_from_stdin_and_output_to_stdout():
     assert command_stdout.decode("utf-8").startswith("<!DOCTYPE html>")
 
 
+@pytest.mark.integration_test
+@pytest.mark.usefixtures("remove_generated_file")
+@pytest.mark.parametrize("arguments, expected_start_string", [
+    (
+        [],
+        '<!DOCTYPE html><html lang="en" class="pf-m-redhat-font">'
+    ),
+    (
+        ["-f", "HTML"],
+        '<!DOCTYPE html><html lang="en" class="pf-m-redhat-font">'
+    ),
+    (
+        ["-f", "OLD-STYLE-HTML"],
+        '<!DOCTYPE html>\n<html lang="en">'
+    ),
+    (
+        ["-f", "JSON"],
+        "{"
+    )
+])
+def test_command_with_different_formats(arguments, expected_start_string):
+    command_stdout = None
+    with subprocess.Popen(CAT_ARF_FILE, stdout=subprocess.PIPE) as cat_command:
+        command_stdout = subprocess.check_output(
+            [OSCAP_REPORT_COMMAND, *arguments], stdin=cat_command.stdout)
+    assert command_stdout.decode("utf-8").startswith(expected_start_string)
+
+
 @pytest.mark.integration_test
 @pytest.mark.usefixtures("remove_generated_file")
 def test_command_with_input_from_file_and_output_to_stdout():
